﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows.Controls;
using Infragistics.Windows.DockManager;

namespace WpfApplication
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void DockManager_PaneDragEnded(object sender, Infragistics.Windows.DockManager.Events.PaneDragEndedEventArgs e)
        {
            var activePane = ((XamDockManager)e.Source).ActivePane;
            if (activePane == null) return;
            var toolWindow = ToolWindow.GetToolWindow(activePane);

            if (toolWindow != null)
            {
                toolWindow.MinHeight = 100;
                toolWindow.MinWidth = 180;
            }
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            var newView = new UserControl1();
            var pane = CreatePane("UserControl1", newView);
            pane.BringIntoView();
        }

        private ContentPane CreatePane(string viewName, object viewContent)
        {
            ContentPane pane = null;

            if (DockManager.HasDocumentContentHost)
            {
                var docHost = DockManager.Content as DocumentContentHost;
                try
                {
                    if (docHost.Panes.Count == 0)
                        docHost.Panes.Add(new SplitPane { SplitterOrientation = Orientation.Vertical });
                    if (docHost.Panes[0].Panes.Count == 0)
                        docHost.Panes[0].Panes.Add(new TabGroupPane());
                    TabGroupPane tgp = GetFirstTagGroupPane(docHost.Panes);
                    if (tgp != null)
                    {
                        pane = new ContentPane { Header = viewName, Content = viewContent };
                        tgp.Items.Insert(0, pane); // insert at left
                    }
                }
                catch (Exception ex)
                {
                    if (pane != null)
                    {
                        pane.Content = null;
                        pane = null;
                    }
                }
            }

            if (pane == null)
            {
                pane = DockManager.AddDocument(viewName, viewContent);
            }


            pane.Name = string.Format("{0}_{1}", viewName, Guid.NewGuid().ToString("N")); //32 digits, see http://msdn.microsoft.com/en-us/library/gg678754.aspx
            pane.Activate();
            return pane;
        }

        private TabGroupPane GetFirstTagGroupPane(IEnumerable<FrameworkElement> panes)
        {
            if (panes == null) return null;
            var pane = panes.FirstOrDefault();
            if (pane is TabGroupPane)
                return (TabGroupPane)pane;
            if (pane is SplitPane)
                return GetFirstTagGroupPane(((SplitPane)pane).Panes);
            return null;
        }
    }
}
